import { createStyles } from '@udecode/plate-styled-components';
import _styled, { css } from 'styled-components';
import * as React from 'react';
import { ELEMENT_CODE_BLOCK, CODE_BLOCK_LANGUAGES_POPULAR, CODE_BLOCK_LANGUAGES, insertEmptyCodeBlock } from '@udecode/plate-code-block';
import { setNodes, getPreventDefaultHandler } from '@udecode/plate-common';
import { useEditorRef, getPlatePluginOptions, useStoreEditorState, useEventEditorId, getPlatePluginType } from '@udecode/plate-core';
import { ReactEditor } from 'slate-react';
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import { ToolbarElement } from '@udecode/plate-toolbar';

const getCodeBlockElementStyles = props => createStyles({
  prefixClassNames: 'CodeBlockElement',
  ...props
}, {
  root: [{
    "whiteSpace": "pre-wrap",
    "paddingTop": "0.75rem",
    "paddingBottom": "0.75rem",
    "paddingLeft": "1rem",
    "paddingRight": "1rem"
  }, css(["font-size:16px;font-family:SFMono-Regular,Consolas,Monaco,'Liberation Mono',Menlo,Courier,monospace;tab-size:2;line-height:normal;border-radius:3px;background-color:rgb(247,246,243);"])]
});

const CodeBlockSelectElement = ({
  lang,
  onChange,
  ...props
}) => {
  const [value, setValue] = React.useState(lang);
  const editor = useEditorRef();
  const code_block = getPlatePluginOptions(editor, ELEMENT_CODE_BLOCK);
  return /*#__PURE__*/jsxs("select", {
    value: value,
    style: {
      float: 'right'
    },
    onClick: e => {
      e.stopPropagation();
    },
    onChange: e => {
      onChange(e.target.value);
      setValue(e.target.value);
    },
    contentEditable: false,
    ...props,
    children: [/*#__PURE__*/jsx("option", {
      value: "",
      children: "Plain text"
    }), (code_block === null || code_block === void 0 ? void 0 : code_block.syntaxPopularFirst) && Object.entries(CODE_BLOCK_LANGUAGES_POPULAR).map(([key, val]) => /*#__PURE__*/jsx("option", {
      value: key,
      children: val
    }, key)), Object.entries(CODE_BLOCK_LANGUAGES).map(([key, val]) => /*#__PURE__*/jsx("option", {
      value: key,
      children: val
    }, key))]
  });
};

const CodeBlockElement = props => {
  const {
    attributes,
    children,
    nodeProps,
    styles,
    element,
    classNames,
    prefixClassNames,
    ...rootProps
  } = props;
  const {
    lang
  } = element;
  const editor = useEditorRef();
  const {
    root
  } = getCodeBlockElementStyles(props);
  const code_block = getPlatePluginOptions(editor, ELEMENT_CODE_BLOCK);
  const codeClassName = lang ? `${lang} language-${lang}` : '';
  return /*#__PURE__*/jsx(Fragment, {
    children: /*#__PURE__*/jsxs(_StyledPre, { ...attributes,
      className: root.className,
      ...rootProps,
      ...nodeProps,
      $_css: root.css,
      children: [(code_block === null || code_block === void 0 ? void 0 : code_block.syntax) && /*#__PURE__*/jsx(CodeBlockSelectElement, {
        "data-testid": "CodeBlockSelectElement",
        lang: lang,
        onChange: val => {
          const path = ReactEditor.findPath(editor, element);
          setNodes(editor, {
            lang: val
          }, {
            at: path
          });
        }
      }), /*#__PURE__*/jsx("code", {
        className: codeClassName,
        children: children
      })]
    })
  });
};

var _StyledPre = _styled("pre").withConfig({
  displayName: "CodeBlockElement___StyledPre",
  componentId: "sc-edret1-0"
})(["", ""], p => p.$_css);

const getCodeLineElementStyles = props => createStyles({
  prefixClassNames: 'CodeLineElement',
  ...props
}, {
  root: [{}]
});

const CodeLineElement = props => {
  const {
    attributes,
    children,
    nodeProps,
    styles,
    element,
    classNames,
    prefixClassNames,
    ...rootProps
  } = props;
  const {
    root
  } = getCodeLineElementStyles(props);
  return /*#__PURE__*/jsx(_StyledDiv, { ...attributes,
    className: root.className,
    ...rootProps,
    ...nodeProps,
    $_css: root.css,
    children: children
  });
};

var _StyledDiv = _styled("div").withConfig({
  displayName: "CodeLineElement___StyledDiv",
  componentId: "sc-11fh9za-0"
})(["", ""], p => p.$_css);

const ToolbarCodeBlock = ({
  options,
  ...props
}) => {
  const editor = useStoreEditorState(useEventEditorId('focus'));
  return /*#__PURE__*/jsx(ToolbarElement, {
    type: getPlatePluginType(editor, ELEMENT_CODE_BLOCK),
    onMouseDown: editor && getPreventDefaultHandler(insertEmptyCodeBlock, editor, {
      insertNodesOptions: {
        select: true
      },
      ...options
    }),
    ...props
  });
};

export { CodeBlockElement, CodeBlockSelectElement, CodeLineElement, ToolbarCodeBlock, getCodeBlockElementStyles, getCodeLineElementStyles };
//# sourceMappingURL=index.es.js.map
