'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var plateStyledComponents = require('@udecode/plate-styled-components');
var _styled = require('styled-components');
var React = require('react');
var plateCodeBlock = require('@udecode/plate-code-block');
var plateCommon = require('@udecode/plate-common');
var plateCore = require('@udecode/plate-core');
var slateReact = require('slate-react');
var jsxRuntime = require('react/jsx-runtime');
var plateToolbar = require('@udecode/plate-toolbar');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__namespace = /*#__PURE__*/_interopNamespace(React);

const getCodeBlockElementStyles = props => plateStyledComponents.createStyles({
  prefixClassNames: 'CodeBlockElement',
  ...props
}, {
  root: [{
    "whiteSpace": "pre-wrap",
    "paddingTop": "0.75rem",
    "paddingBottom": "0.75rem",
    "paddingLeft": "1rem",
    "paddingRight": "1rem"
  }, _styled.css(["font-size:16px;font-family:SFMono-Regular,Consolas,Monaco,'Liberation Mono',Menlo,Courier,monospace;tab-size:2;line-height:normal;border-radius:3px;background-color:rgb(247,246,243);"])]
});

const CodeBlockSelectElement = ({
  lang,
  onChange,
  ...props
}) => {
  const [value, setValue] = React__namespace.useState(lang);
  const editor = plateCore.useEditorRef();
  const code_block = plateCore.getPlatePluginOptions(editor, plateCodeBlock.ELEMENT_CODE_BLOCK);
  return /*#__PURE__*/jsxRuntime.jsxs("select", {
    value: value,
    style: {
      float: 'right'
    },
    onClick: e => {
      e.stopPropagation();
    },
    onChange: e => {
      onChange(e.target.value);
      setValue(e.target.value);
    },
    contentEditable: false,
    ...props,
    children: [/*#__PURE__*/jsxRuntime.jsx("option", {
      value: "",
      children: "Plain text"
    }), (code_block === null || code_block === void 0 ? void 0 : code_block.syntaxPopularFirst) && Object.entries(plateCodeBlock.CODE_BLOCK_LANGUAGES_POPULAR).map(([key, val]) => /*#__PURE__*/jsxRuntime.jsx("option", {
      value: key,
      children: val
    }, key)), Object.entries(plateCodeBlock.CODE_BLOCK_LANGUAGES).map(([key, val]) => /*#__PURE__*/jsxRuntime.jsx("option", {
      value: key,
      children: val
    }, key))]
  });
};

const CodeBlockElement = props => {
  const {
    attributes,
    children,
    nodeProps,
    styles,
    element,
    classNames,
    prefixClassNames,
    ...rootProps
  } = props;
  const {
    lang
  } = element;
  const editor = plateCore.useEditorRef();
  const {
    root
  } = getCodeBlockElementStyles(props);
  const code_block = plateCore.getPlatePluginOptions(editor, plateCodeBlock.ELEMENT_CODE_BLOCK);
  const codeClassName = lang ? `${lang} language-${lang}` : '';
  return /*#__PURE__*/jsxRuntime.jsx(jsxRuntime.Fragment, {
    children: /*#__PURE__*/jsxRuntime.jsxs(_StyledPre, { ...attributes,
      className: root.className,
      ...rootProps,
      ...nodeProps,
      $_css: root.css,
      children: [(code_block === null || code_block === void 0 ? void 0 : code_block.syntax) && /*#__PURE__*/jsxRuntime.jsx(CodeBlockSelectElement, {
        "data-testid": "CodeBlockSelectElement",
        lang: lang,
        onChange: val => {
          const path = slateReact.ReactEditor.findPath(editor, element);
          plateCommon.setNodes(editor, {
            lang: val
          }, {
            at: path
          });
        }
      }), /*#__PURE__*/jsxRuntime.jsx("code", {
        className: codeClassName,
        children: children
      })]
    })
  });
};

var _StyledPre = _styled__default['default']("pre").withConfig({
  displayName: "CodeBlockElement___StyledPre",
  componentId: "sc-edret1-0"
})(["", ""], p => p.$_css);

const getCodeLineElementStyles = props => plateStyledComponents.createStyles({
  prefixClassNames: 'CodeLineElement',
  ...props
}, {
  root: [{}]
});

const CodeLineElement = props => {
  const {
    attributes,
    children,
    nodeProps,
    styles,
    element,
    classNames,
    prefixClassNames,
    ...rootProps
  } = props;
  const {
    root
  } = getCodeLineElementStyles(props);
  return /*#__PURE__*/jsxRuntime.jsx(_StyledDiv, { ...attributes,
    className: root.className,
    ...rootProps,
    ...nodeProps,
    $_css: root.css,
    children: children
  });
};

var _StyledDiv = _styled__default['default']("div").withConfig({
  displayName: "CodeLineElement___StyledDiv",
  componentId: "sc-11fh9za-0"
})(["", ""], p => p.$_css);

const ToolbarCodeBlock = ({
  options,
  ...props
}) => {
  const editor = plateCore.useStoreEditorState(plateCore.useEventEditorId('focus'));
  return /*#__PURE__*/jsxRuntime.jsx(plateToolbar.ToolbarElement, {
    type: plateCore.getPlatePluginType(editor, plateCodeBlock.ELEMENT_CODE_BLOCK),
    onMouseDown: editor && plateCommon.getPreventDefaultHandler(plateCodeBlock.insertEmptyCodeBlock, editor, {
      insertNodesOptions: {
        select: true
      },
      ...options
    }),
    ...props
  });
};

exports.CodeBlockElement = CodeBlockElement;
exports.CodeBlockSelectElement = CodeBlockSelectElement;
exports.CodeLineElement = CodeLineElement;
exports.ToolbarCodeBlock = ToolbarCodeBlock;
exports.getCodeBlockElementStyles = getCodeBlockElementStyles;
exports.getCodeLineElementStyles = getCodeLineElementStyles;
//# sourceMappingURL=index.js.map
